@@ -123,6 +123,7 @@ void win_struct_init(win_struct *win)
 
   win->window_manager=NULL;
   win->gnome=FALSE;
+  win->compiz=FALSE;
   win->kde=FALSE;
 
   win->no_reparent=FALSE;
@@ -169,8 +170,8 @@ void command_line_init (win_struct *win, int argc, char **argv)
 
   if (debug) printf ("window manager: %s\n", win->window_manager);
 
-  if (!strcmp(win->window_manager, "Metacity")) {
-
+  if ((!strcmp(win->window_manager, "Metacity"))) {
+    
     #ifndef GCONF_NOT_DISABLED
           printf ("\n\nAlltray: To use Alltray under Gnome, Gconf support should not be disabled.\n"
                   "         But it is.\n\n");
@@ -181,6 +182,16 @@ void command_line_init (win_struct *win, int argc, char **argv)
     win->no_reparent=TRUE;
   }
 
+  if (!strcmp(win->window_manager, "compiz")) {
+    #ifndef GCONF_NOT_DISABLED
+          printf ("\n\nAlltray: To use Alltray with Compiz, Gconf support should not be disabled.\n"
+                  "         But it is.\n\n");
+          exit (0);
+    #endif 
+
+     win->compiz = TRUE;
+  }
+
   if (!strcmp(win->window_manager, "KWin")) {
      win->kde=TRUE;
      win->no_reparent=TRUE;
@@ -226,7 +237,7 @@ void command_line_init (win_struct *win, int argc, char **argv)
   }
 
   if (configure && !win->kde) {
-    printf ("\n\nAlltray: \"--configure\" option only usefull for the KDE desktop.\n\n");
+    printf ("\n\nAlltray: \"--configure\" option only useful for the KDE desktop.\n\n");
     exit (0);
   }
 
@@ -237,6 +248,7 @@ void command_line_init (win_struct *win, int argc, char **argv)
 
     win->gnome=FALSE;
     win->kde=FALSE;
+    win->compiz=FALSE;
     win->no_reparent=TRUE;
   }
 
@@ -363,10 +375,15 @@ main (int argc, char *argv[])
   if (!win->click_mode && !win->notray)
     wait_for_manager(win);
 
-  if (!win->click_mode)
+  if (!win->click_mode) {
     exec_and_wait_for_window(win);
-  else
+  } else {
+    if(win->compiz) {
+      win->no_reparent = TRUE;
+    }
+
     click_mode(win);
+  }
 
   if (win->xmms) {
     win->xmms_main_window_gdk=gdk_window_foreign_new(win->xmms_main_window_xlib);
