@@ -5,7 +5,7 @@
 
 gboolean parse_arguments(int argc, char **argv, gchar **icon,
     gchar  **rest, gboolean *show, gboolean *debug, gboolean *borderless, gboolean *sticky,
-    gboolean *skip_tasklist, gboolean *no_title, gboolean *configure, gboolean *large_icons, 
+    gboolean *skip_tasklist, gboolean *configure, gboolean *large_icons,
     GArray *command_menu, gint *title_time, gchar **geometry,
     unsigned int *shortcut_key, unsigned int *shortcut_modifier, gboolean *notray, gboolean *nomini);
 
@@ -16,7 +16,7 @@ void show_version(void);
 void wait_for_manager(win_struct *win);
 gboolean append_command_to_menu(GArray *command_menu,
   gchar *string);
-  
+
 void update_visibility_state (win_struct *win, gboolean new_state);
 
 #endif
