@@ -24,6 +24,7 @@
  * Copyright:
  *
  *    Jochen Baier, 2004, 2005, 2006 (email@Jochen-Baier.de)
+ *    Portions by Michael B. Trausch, 2007, 2008 (mike@trausch.us)
  *
  *
  * Based on code from:
@@ -1465,16 +1466,44 @@ void update_window_title(win_struct *win)
   }
 
   title= wnck_get_name (child);
-  if (!title) {
-   return;
-  }
+ 
+  if (title) {
+    char *title_string = NULL;
+    
+    if (debug) printf ("title: %s\n", title);
 
+    if (!win->xmms && win->no_reparent && g_str_has_suffix (title,"(AllTray)")) {
+      g_free (title);
+      return;
+    }
 
-   if (debug) printf ("title: %s\n", title);
-
-    if (!win->no_reparent) {
-      gdk_window_set_title (win->parent_gdk, title);
+    // Interact nicely with Compiz, which works slightly differently.
+    // We use get_window_manager() instead of win->window_manager because
+    // win->window_manager is not always populated when running under
+    // Compiz.
+    if ((!strcasecmp(get_window_manager(), "compiz")) && (win->no_title)
+        && (!win->xmms)) {
+      title_string = title;
+      if (win->no_reparent) {
+        gdk_window_set_title(win->child_gdk, title_string);
+      } else {
+        gdk_window_set_title(win->parent_gdk, title_string);
       }
+    }
+
+    if (!win->xmms) {
+      title_string=g_strconcat (title, " (AllTray)", NULL);
+
+    if (!win->no_title) {
+      
+      if (win->no_reparent)
+        gdk_window_set_title (win->child_gdk, title_string);
+      else
+        gdk_window_set_title (win->parent_gdk, title_string);
+    }
+
+      g_free (title_string);
+    }
 
     if (win->title)
       g_free (win->title);
@@ -1493,12 +1522,13 @@ void update_window_title(win_struct *win)
 
 
     if (debug) printf ("win->title: %s\n", win->title);
+    gtk_widget_set_tooltip_text(win->plug, win->title);
     g_free(title);
 
     if (win->title_time) {
       show_balloon (win, win->title, win->title_time);
     }
-
+  }
 }
 
 void close_window (Window window)
@@ -1688,7 +1718,6 @@ void destroy_all_and_exit (win_struct *win, gboolean kill_child)
   g_free (win);
 
   gtk_main_quit ();
-
 }
 
 static GdkFilterReturn parent_filter_map (GdkXEvent *xevent,
@@ -1893,8 +1922,6 @@ void show_hide_window (win_struct *win, gint force_state,
       if (win->sticky)
         sticky (parent_xlib);
 
-      skip_pager(parent_xlib, TRUE);
-
       if (win->skip_tasklist)
         skip_taskbar (win, TRUE);
 
